middleware

package
v0.0.0-...-5b3ac6b Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 27, 2023 License: MIT Imports: 8 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func AuthorizeRolesMiddleware

func AuthorizeRolesMiddleware(permissions []string) gin.HandlerFunc

Reads The Acces Token and Refresh Token and authorize the roles also authorize the header of ssid of user id Reads the refresh token checks the token_v validity generets access token => returns to header => to retry the request

Types

This section is empty.

Jump to