Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AuthorizeRolesMiddleware ¶
func AuthorizeRolesMiddleware(permissions []string) gin.HandlerFunc
Reads The Acces Token and Refresh Token and authorize the roles also authorize the header of ssid of user id Reads the refresh token checks the token_v validity generets access token => returns to header => to retry the request
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.